Faucet VM
=========

Viewing documentation
---------------------

Docs for the virtual machine image are viewable on `docs.faucet.nz <http://docs.faucet.nz/en/latest/installation.html#virtual-machine-image>`_.
